function [stationary]=isStationary(trce)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% This script checks if a trace is stationary using simple heuristics of
%%%% checking short-term changes and long-term changes
%%%% INPUT:
%%%%       (1) The trace
%%%%       (2) The filtering parameters: shortTerm and longTerm
%%%% OUTPUT: stationary =1 if the trace is not stationary, 0 otherwise
%%%% COPYRIGHT : Hung X. Nguyen, the University of Adelaide, Australia
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%% parameters -- tuning these parameters for different heuristics
shortTerm=0.05;
longTerm=0.15;
window=1000;
stationary=1;


%%%%% moving average
AveTrce=[];
AveTrce =filter(ones(window,1),window,trce);
AveTrce=AveTrce(window:length(AveTrce));

%%%%% short-term variation
for i=501:length(AveTrce)-500
    if max(AveTrce(i-500:i+500))-min(AveTrce(i-500:i+500)) >shortTerm
        stationary=0;
        break;
    end
end

%%%% long-term variation
if (stationary==1)
    p=polyfit(1:length(AveTrce),AveTrce',1);
    
    if (abs(1*p(1)-length(AveTrce)*p(1)) >longTerm)
        stationary=0;
    end
end


